==> ansela_0.8-1.tar.gz: ansela-0.8/src/opt/anselA/core/buttons.py <==
from files import *
from filters.bw import *
from filters.colors import *
from filters.crop import *
from filters.levels import *
from filters.rotate import *
from filters.simple import *


#######################################
#   Apply
#######################################
def ApplyGo(self):
    print "To Apply"
    ToggleThumbWait(self, True)
    if (self.core.valCurTab == 1):
        Convert_BW(self, self.core.current.image, self.core.valBW, True)
    elif (self.core.valCurTab == 2):
        Simple_Adjustments(self, self.core.current.image, "Any", True)
    elif (self.core.valCurTab == 3):
        Adjust_ColorLevel(self, self.core.current.image, "Any", True)
    elif (self.core.valCurTab == 4):
        Adjust_ToneLevel(self, self.core.current.image, "Any", True)
    elif (self.core.valCurTab == 5):
        RotateApply(self,  self.core.valRot)
    elif (self.core.valCurTab==7):
        CropApply(self, self.core.current.image,  "", True)

    SlidersReset(self)
    FileImageRefresh(self)
    showUpdateLabel(self, False,  False)
    ShowApply(self, False)
    ToggleThumbWait(self, False)
    
def cSlide_SetValue(self, value, coreVal, qTextbox,  qSlider,  cSource = "Any"):
    coreVal  = value
    tab =self.core.GetCurrentTab(self)
    qTextbox.setText(str(coreVal))
    if  (self.core.displayUpdating == False):
        if (tab == 2):
            Simple_Adjustments(self, self.core.current.thumb, cSource,  False)
        elif (tab == 3):
            Adjust_ColorLevel(self, self.core.current.thumb, cSource, False)
        elif (tab == 4):
            Adjust_ToneLevel(self, self.core.current.thumb,  cSource,  False)
    return coreVal

def SlidersReset(self):
    self.core.displayUpdating = True
    self.cSlide_B.setValue(0)
    self.cSlide_Br.setValue(0)
    self.cSlide_Co.setValue(0)
    self.cSlide_G.setValue(0)
    self.cSlide_Hi.setValue(0)
    self.cSlide_Mi.setValue(0)
    self.cSlide_R.setValue(0)
    self.cSlide_Sa.setValue(0)
    self.cSlide_Sh.setValue(0)
    self.cSlide_Sw.setValue(0)
    self.dial.setValue(0)
    self.cropScrollTop.setValue(0)
    self.cropScrollBottom.setValue(99)
    self.cropScrollLeft.setValue(0)
    self.cropScrollRight.setValue(99)
    self.PopSizes()
    self.repaint()
    self.core.displayUpdating = False
              
#######################################
#   Undo
#######################################
def UndoGo(self):
    self.core.UndoImage_Set()
    self.loadUndoImages()
    
    ToggleThumbWait(self, True)
    FullScreenToggle(self, False)
    FileImageRefresh(self)
        
    self.btnApplyUndo.setText(":"+str(self.core.undoCount))
    ToggleThumbWait(self, False)

==> ansela_0.9-0.tar.gz: ansela-0.9/src/opt/anselA/core/buttons.py <==
from files import *
from filters.bw import *
from filters.colors import *
from filters.crop import *
from filters.levels import *
from filters.rotate import *
from filters.simple import *


#######################################
#   Apply
#######################################
def ApplyGo(self):
        
    #print(str(self.core.valCurTab))
    
    #stop thumb wait too slow and odd.
    #tim=time.time()
    ToggleThumbWait(self, True)
    if (self.core.valCurTab == 1):
        Convert_BW(self, self.core.current.image, self.core.valBW, True)
    elif (self.core.valCurTab == 2):
        Simple_Adjustments(self, self.core.current.image, "Any", True)
    elif (self.core.valCurTab == 3):
        Adjust_ColorLevel(self, self.core.current.image, "Any", True)
    elif (self.core.valCurTab == 4):
        Adjust_ToneLevel(self, self.core.current.image, "Any", True)
    elif (self.core.valCurTab == 5):
        RotateApply(self,  self.core.valRot)
    elif (self.core.valCurTab==7):
        CropApply(self, self.core.current.image,  "", True)
    
    #print("Apply Time: "+str(time.time()-tim))
    
    SlidersReset(self)
    FileImageRefresh(self)
    ToggleThumbWait(self, False)
    showUpdateLabel(self, False,  False)
    ShowApply(self, False)    
    
def cSlide_SetValue(self, value, coreVal, qTextbox,  qSlider,  cSource = "Any",  UpdatingLock=False):
    if UpdatingLock:
        qTextbox.setText(str(value))
        coreVal=value
    else:
        coreVal  = value
        tab =self.core.GetCurrentTab(self)
        qTextbox.setText(str(coreVal))
        if  (self.core.displayUpdating == False):
            if (tab == 2):
                Simple_Adjustments(self, self.core.current.thumb, cSource,  False)
            elif (tab == 3):
                Adjust_ColorLevel(self, self.core.current.thumb, cSource, False)
            elif (tab == 4):
                Adjust_ToneLevel(self, self.core.current.thumb,  cSource,  False)
    return coreVal

def SlidersReset(self):
    self.core.displayUpdating = True
    self.cSlide_B.setValue(0)
    self.cSlide_Br.setValue(0)
    self.cSlide_Co.setValue(0)
    self.cSlide_G.setValue(0)
    self.cSlide_Hi.setValue(0)
    self.cSlide_Mi.setValue(0)
    self.cSlide_R.setValue(0)
    self.cSlide_Sa.setValue(0)
    self.cSlide_Sh.setValue(0)
    self.cSlide_Sw.setValue(0)
    self.dial.setValue(0)
    self.cropScrollTop.setValue(0)
    self.cropScrollBottom.setValue(99)
    self.cropScrollLeft.setValue(0)
    self.cropScrollRight.setValue(99)
    self.PopSizes()
    self.repaint()
    self.core.displayUpdating = False
              
#######################################
#   Undo
#######################################
def UndoGo(self):
    self.core.UndoImage_Set()
    self.loadUndoImages()
    
    ToggleThumbWait(self, True)
    FullScreenToggle(self, False)
    FileImageRefresh(self)
        
    self.btnApplyUndo.setText(":"+str(self.core.undoCount))
    ToggleThumbWait(self, False)
